#
# spec file for package python-iniconfig
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -%{flavor}
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-iniconfig%{psuffix}
Version:        2.1.0
Release:        1.1
Summary:        iniconfig: brain-dead simple config-ini parsing
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/RonnyPfannschmidt/iniconfig
Source:         https://files.pythonhosted.org/packages/source/i/iniconfig/iniconfig-%{version}.tar.gz
Source1:        https://github.com/pytest-dev/iniconfig/archive/refs/tags/v%{version}.tar.gz#/iniconfig-%{version}-tests.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module hatch_vcs}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module iniconfig}
BuildRequires:  %{python_module pytest}
%endif
%python_subpackages

%description
iniconfig is a small and simple INI-file parser module
having a unique set of features:

* tested against Python2.4 across to Python3.2, Jython, PyPy
* maintains order of sections and entries
* supports multi-line values with or without line-continuations
* supports "#" comments everywhere
* raises errors with proper line-numbers
* no bells and whistles like automatic substitutions
* iniconfig raises an Error if two sections have the same name.

%prep
%setup -q -n iniconfig-%{version} -a1

%if !%{with test}
%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
%pytest
%endif

%if !%{with test}
%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/iniconfig
%{python_sitelib}/iniconfig-%{version}.dist-info
%endif

%changelog
* Tue Jun  3 2025 Nico Krapp <nico.krapp@suse.com>
- Update to 2.1.0
  * fix #26 - list individuals in license file by @RonnyPfannschmidt in #52
  * Run tests in CI by @nicoddemus in #53
  * Use pypa/gh-action-pypi-publish@release/v1 @ GHA by @webknjaz in #54
  * Add support for Python 3.12-3.13 and drop EOL 3.7 by @hugovk in #56
* Mon May  1 2023 Benjamin Greiner <code@bnavigator.de>
- Don't catchall filelist
- Clean dependencies
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Sun Jan 29 2023 Dirk Müller <dmueller@suse.com>
- update to 2.0.0:
  * Drop Python 3.6
  * Add Python 3.11 support
  * type hints added
- use gh tarball for tests
* Mon Dec  5 2022 Daniel Garcia <daniel.garcia@suse.com>
- Add python-py as test dependency
* Wed Jul 20 2022 Steve Kowalik <steven.kowalik@suse.com>
- BuildRequire itself when building test flavour.
* Mon Mar 14 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Include in SLE-15 (bsc#1195916, bsc#1196696, jsc#PM-3356, jsc#SLE-23972)
* Tue Nov 10 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.1.1:
  * fix version determination (thanks @florimondmanca)
  * typing stubs (thanks @bluetech)
* Mon Aug 24 2020 Marketa Calabkova <mcalabkova@suse.com>
- Initial packaging (v1.0.1)
- Build the tests separately because it deadlocks with pytest
